:mod:`art.defences.trainer`
===========================
.. automodule:: art.defences.trainer

Base Class Trainer
------------------
.. autoclass:: Trainer
   :members:
   :special-members:

Adversarial Training
--------------------
.. autoclass:: AdversarialTrainer
   :members:
   :special-members:

Adversarial Training Madry PGD
------------------------------
.. autoclass:: AdversarialTrainerMadryPGD
   :members:
   :special-members:

Base Class Adversarial Training Fast is Better than Free
--------------------------------------------------------
.. autoclass:: AdversarialTrainerFBF
   :members:
   :special-members:

Adversarial Training Fast is Better than Free - PyTorch
-------------------------------------------------------
.. autoclass:: AdversarialTrainerFBFPyTorch
   :members:
   :special-members:
